import Config

# config/runtime.exs is executed for all environments, including
# during releases. It is executed after compilation and before the
# system starts, so it is typically used to load production configuration
# and secrets from environment variables or elsewhere. Do not define
# any compile-time configuration in here, as it won't be applied.
# The block below contains prod specific runtime configuration.

if System.get_env("PHX_SERVER") do
  config :freedive, FreediveWeb.Endpoint, server: true
end

if config_env() == :prod do
  # Account registration in production is disabled by default.
  # To enable, set the REGISTER_ACCOUNT_ENABLE environment variable to "true".
  if System.get_env("REGISTER_ACCOUNT_ENABLE") != "true" do
    config :freedive, :features, register_account: false
  end

  # Colorhash feature is enabled by default.
  # To disable, set the COLORHASH_ENABLE environment variable to "false".
  if System.get_env("COLORHASH_ENABLE") == "false" do
    config :freedive, :features, colorhash: false
  end

  database_path =
    System.get_env("DATABASE_PATH") ||
      raise """
      environment variable DATABASE_PATH is missing.
      For example: /etc/freedive/freedive.db
      """

  config :freedive, Freedive.Repo,
    database: database_path,
    pool_size: String.to_integer(System.get_env("POOL_SIZE") || "5")

  # The secret key base is used to sign/encrypt cookies and other secrets.
  # A default value is used in config/dev.exs and config/test.exs but you
  # want to use a different value for prod and you most likely don't want
  # to check this value into version control, so we use an environment
  # variable instead.
  secret_key_base =
    System.get_env("SECRET_KEY_BASE") ||
      raise """
      environment variable SECRET_KEY_BASE is missing.
      You can generate one by calling: mix phx.gen.secret
      """

  # config :freedive, :dns_cluster_query, System.get_env("DNS_CLUSTER_QUERY")

  host = System.get_env("HOST") || "localhost"
  bind = System.get_env("BIND") || "local4"
  port = String.to_integer(System.get_env("PORT") || "5443")
  ip = PhxConfigUtil.BindToIp.parse!(bind)

  config :freedive, :dns_cluster_query, System.get_env("DNS_CLUSTER_QUERY")

  config :freedive, FreediveWeb.Endpoint,
    url: [host: host, port: port, scheme: "https"],
    https: [
      ip: ip,
      port: port,
      cipher_suite: :strong,
      keyfile: System.get_env("TLS_KEY_PATH"),
      certfile: System.get_env("TLS_CERT_PATH")
    ],
    secret_key_base: secret_key_base

  # ## Configuring the mailer
  #
  # In production you need to configure the mailer to use a different adapter.
  # Also, you may need to configure the Swoosh API client of your choice if you
  # are not using SMTP. Here is an example of the configuration:
  #
  #     config :freedive, Freedive.Mailer,
  #       adapter: Swoosh.Adapters.Mailgun,
  #       api_key: System.get_env("MAILGUN_API_KEY"),
  #       domain: System.get_env("MAILGUN_DOMAIN")
  #
  # For this example you need include a HTTP client required by Swoosh API client.
  # Swoosh supports Hackney and Finch out of the box:
  #
  #     config :swoosh, :api_client, Swoosh.ApiClient.Hackney
  #
  # See https://hexdocs.pm/swoosh/Swoosh.html#module-installation for details.
end
